Uf enum
Brazilian federative unit (26 states + DF).
Values
- ac → const Uf
-
Acre.
const Uf('AC') - al → const Uf
-
Alagoas.
const Uf('AL') - am → const Uf
-
Amazonas.
const Uf('AM') - ap → const Uf
-
Amapá.
const Uf('AP') - ba → const Uf
-
Bahia.
const Uf('BA') - ce → const Uf
-
Ceará.
const Uf('CE') - df → const Uf
-
Distrito Federal.
const Uf('DF') - es → const Uf
-
Espírito Santo.
const Uf('ES') - go → const Uf
-
Goiás.
const Uf('GO') - ma → const Uf
-
Maranhão.
const Uf('MA') - mg → const Uf
-
Minas Gerais.
const Uf('MG') - ms → const Uf
-
Mato Grosso do Sul.
const Uf('MS') - mt → const Uf
-
Mato Grosso.
const Uf('MT') - pa → const Uf
-
Pará.
const Uf('PA') - pb → const Uf
-
Paraíba.
const Uf('PB') - pe → const Uf
-
Pernambuco.
const Uf('PE') - pi → const Uf
-
Piauí.
const Uf('PI') - pr → const Uf
-
Paraná.
const Uf('PR') - rj → const Uf
-
Rio de Janeiro.
const Uf('RJ') - rn → const Uf
-
Rio Grande do Norte.
const Uf('RN') - ro → const Uf
-
Rondônia.
const Uf('RO') - rr → const Uf
-
Roraima.
const Uf('RR') - rs → const Uf
-
Rio Grande do Sul.
const Uf('RS') - sc → const Uf
-
Santa Catarina.
const Uf('SC') - se → const Uf
-
Sergipe.
const Uf('SE') - sp → const Uf
-
São Paulo.
const Uf('SP') - to → const Uf
-
Tocantins.
const Uf('TO')
Properties
- code → String
-
Two-letter IBGE/postal code.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited